/*
 * Definitions for libfsrefs
 *
 * Copyright (C) 2012-2021, Joachim Metz <joachim.metz@gmail.com>
 *
 * Refer to AUTHORS for acknowledgements.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#if !defined( _LIBFSREFS_DEFINITIONS_H )
#define _LIBFSREFS_DEFINITIONS_H

#include <libfsrefs/types.h>

#define LIBFSREFS_VERSION					20210422

/* The version string
 */
#define LIBFSREFS_VERSION_STRING				"20210422"

/* The file access
 * bit 1        set to 1 for read access
 * bit 2        set to 1 for write access
 * bit 3-8      not used
 */
enum LIBFSREFS_ACCESS_FLAGS
{
	LIBFSREFS_ACCESS_FLAG_READ				= 0x01,
/* Reserved: not supported yet */
	LIBFSREFS_ACCESS_FLAG_WRITE				= 0x02
};

/* The file access macros
 */
#define LIBFSREFS_OPEN_READ					( LIBFSREFS_ACCESS_FLAG_READ )
/* Reserved: not supported yet */
#define LIBFSREFS_OPEN_WRITE					( LIBFSREFS_ACCESS_FLAG_WRITE )
/* Reserved: not supported yet */
#define LIBFSREFS_OPEN_READ_WRITE				( LIBFSREFS_ACCESS_FLAG_READ | LIBFSREFS_ACCESS_FLAG_WRITE )

/* The file attribute flags
 */
enum LIBFSREFS_FILE_ATTRIBUTE_FLAGS
{
	LIBFSREFS_FILE_ATTRIBUTE_FLAG_READ_ONLY			= 0x00000001UL,
	LIBFSREFS_FILE_ATTRIBUTE_FLAG_HIDDEN			= 0x00000002UL,
	LIBFSREFS_FILE_ATTRIBUTE_FLAG_SYSTEM			= 0x00000004UL,

	LIBFSREFS_FILE_ATTRIBUTE_FLAG_DIRECTORY			= 0x00000010UL,
	LIBFSREFS_FILE_ATTRIBUTE_FLAG_ARCHIVE			= 0x00000020UL,
	LIBFSREFS_FILE_ATTRIBUTE_FLAG_DEVICE			= 0x00000040UL,
	LIBFSREFS_FILE_ATTRIBUTE_FLAG_NORMAL			= 0x00000080UL,
	LIBFSREFS_FILE_ATTRIBUTE_FLAG_TEMPORARY			= 0x00000100UL,
	LIBFSREFS_FILE_ATTRIBUTE_FLAG_SPARSE_FILE		= 0x00000200UL,
	LIBFSREFS_FILE_ATTRIBUTE_FLAG_REPARSE_POINT		= 0x00000400UL,
	LIBFSREFS_FILE_ATTRIBUTE_FLAG_COMPRESSED		= 0x00000800UL,
	LIBFSREFS_FILE_ATTRIBUTE_FLAG_OFFLINE			= 0x00001000UL,
	LIBFSREFS_FILE_ATTRIBUTE_FLAG_NOT_CONTENT_INDEXED	= 0x00002000UL,
	LIBFSREFS_FILE_ATTRIBUTE_FLAG_ENCRYPTED			= 0x00004000UL,

	LIBFSREFS_FILE_ATTRIBUTE_FLAG_VIRTUAL			= 0x00010000UL
};

#endif /* !defined( _LIBFSREFS_DEFINITIONS_H ) */

